@@ -35,10 +35,14 @@ class parse(object):
         if not os.path.exists(self.directory):
             mkdir(self.directory)
         output = open(self.filename, 'wb')
+        key = 'updated_parsed'
         if not item:
-            pickle.dump(self.feed['items'][0]['updated_parsed'], output)
+            if 'published_parsed' in self.feed['items'][0]:
+                key = 'published_parsed'
+            pickle.dump(self.feed['items'][0][key], output)
         else:
-            pickle.dump(item['updated_parsed'], output)
+            if 'published_parsed' in item:
+                pickle.dump(item[key], output)
         output.close()
 
     def getlastRead(self):
